pub struct ProcMacros(Id);Expand description
The proc macros. Do not use Self::get! Use Self::get_for_crate instead.
Tuple Fields
0: IdImplementations
Sourceimpl ProcMacros
impl ProcMacros
pub fn ingredient(db: &dyn Database) -> &IngredientImpl<Self>
fn ingredient_(zalsa: &Zalsa) -> &IngredientImpl<Self>
pub fn ingredient_mut( zalsa_mut: &mut Zalsa, ) -> (&mut IngredientImpl<Self>, &mut Runtime)
Sourceimpl ProcMacros
impl ProcMacros
pub fn new<Db_>(
db: &Db_,
by_crate: FxHashMap<Crate, Arc<CrateProcMacros>>,
) -> Selfwhere
Db_: ?Sized + Database,
pub fn builder( by_crate: FxHashMap<Crate, Arc<CrateProcMacros>>, ) -> <Self as HasBuilder>::Builder
pub fn by_crate<'db, Db_>(
self,
db: &'db Db_,
) -> &'db FxHashMap<Crate, Arc<CrateProcMacros>>where
Db_: ?Sized + Database,
pub fn set_by_crate<'db, Db_>(
self,
db: &'db mut Db_,
) -> impl Setter<FieldTy = FxHashMap<Crate, Arc<CrateProcMacros>>>where
Db_: ?Sized + Database,
pub fn try_get<Db_>(db: &Db_) -> Option<Self>where
Db_: ?Sized + Database,
pub fn get<Db_>(db: &Db_) -> Selfwhere
Db_: ?Sized + Database,
Sourcepub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Resultwhere
for<'__trivial_bounds> FxHashMap<Crate, Arc<CrateProcMacros>>: Debug,
pub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Resultwhere
for<'__trivial_bounds> FxHashMap<Crate, Arc<CrateProcMacros>>: Debug,
Default debug formatting for this struct (may be useful if you define your own Debug impl)
Sourceimpl ProcMacros
impl ProcMacros
pub fn init_default(db: &dyn SourceDatabase, durability: Durability)
Sourceimpl ProcMacros
impl ProcMacros
Sourcepub fn get_for_crate<'db>(
db: &'db dyn SourceDatabase,
krate: Crate,
) -> <Option<Arc<CrateProcMacros>> as SalsaAsRef>::AsRef<'db>
pub fn get_for_crate<'db>( db: &'db dyn SourceDatabase, krate: Crate, ) -> <Option<Arc<CrateProcMacros>> as SalsaAsRef>::AsRef<'db>
Incrementality query to prevent queries from directly depending on Self::get.